#' False Positive Rate Control in Selection Frequency for Random Forest
#'
#' This package is an implementation of the methods described by Ender Konukoglu and Melanie Ganz in
#' *Konukoglu, E. and Ganz, M., 2014. Approximate false positive rate control in selection frequency
#' for random forest. arXiv preprint arXiv:1410.2838* <https://arxiv.org/abs/1410.2838>.
#'
#' @docType package
#' @name forestControl-package
#' @useDynLib forestControl
#' @importFrom Rcpp sourceCpp

globalVariables('.')
